SPEECH_T5_FILES = {
    "microsoft/speecht5_tts": [
        "added_tokens.json",
        "config.json",
        "preprocessor_config.json",
        "pytorch_model.bin",
        "special_tokens_map.json",
        "spm_char.model",
        "tokenizer_config.json",
    ],
    "microsoft/speecht5_hifigan": [
        "config.json",
        "pytorch_model.bin",
    ],
    "datasets/w4ffl35/speecht5_speaker_embeddings": [
        "speaker_embeddings"
    ]
}
